---
QUILL: usaf_memo
letterhead_title: DEPARTMENT OF THE AIR FORCE
letterhead_caption:
  - AFROTC DETACHMENT 730
  - UNIVERSITY OF PITTSBURGH, PA
memo_for:
  - AFROTC DET 730/CC
memo_from: !fill
  - 2d Lt First M. Last
subject: !fill DD Month YYYY – DD Month YYYY, Special Pass Request
references:
  - DAFI 36-3003, 07 August 2024, Military Leave Program
signature_block: !fill
  - FIRST M. LAST, 2d Lt, USAF
  - AFIT Masters Student
font_size: 11
---
<!--------------
In the data above, edit;
  - Memorandum From
  - Signature Block
  - Subject
---------------->
**PURPOSE:** The purpose of the memorandum is to request a 4-day pass, in accordance with DAFI 36-3003, for traveling to <<Area 51 for personal research>>.

<!-------------
In Narrative section below, edit:
- Flight and transit details
- Document completion of AF4392 if age 25 or under
--------------->
**NARRATIVE:** On <<DD Month YYYY>>, depart via <<UA2424 at 0240 ET>>. On <<DD Month YYYY>>, return via <<UA1234 at 1300 ET>>. Transit to and from <<PIT with POV>>. I do not need to complete AF4392 to comply with travel risk requirements because I am not under the age of 26.

**REFERENCED REGULATION:** “5.3. Special Pass. Unit commanders may award 3 or 4-day special passes for special occasions or circumstances, such as reenlistment or for some type of special recognition or compensatory time off. They may delegate approval to a level no lower than squadron section commander, deputies, or equivalents. (T-1) Special passes start after normal working hours on a given day. They stop at the beginning of normal working hours on either the 4th day for a 3 -day special pass or the 5th day for a 4-day special pass. A 3-day special pass can be Friday through Sunday, Saturday through Monday, or Tuesday through Thursday. A 4-day special pass can be Thursday through Sunday or Saturday through Tuesday or Friday through Monday. This applies to a normal Monday through Friday workweek. See paragraph 2.1.2 for safe travel guidelines.”

If you have any questions, please contact me at <<airman.snuffy@us.af.mil>> or <<(123) 456-7890>>.

---
CARD: indorsement
signature_block:
  - ROBERT T. CHANCE, Lt Col, USAF
  - Commander
format: informal
---